Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Account ¶
type Account struct {
ID int64 `gorm:"primary_key;auto_increment:false"`
DisplayName string `gorm:"unique;not null"`
}
Account is model represent user and channel in database
type Message ¶
type Message struct {
MsgID uuid.UUID `gorm:"type:uuid;primary_key"`
Timestamp time.Time `gorm:"not null;column:ts"`
MsgText string `gorm:"not null"`
UserRole string `gorm:"type:bit(3);default:b'000'"`
Room Account `gorm:"foreignkey:RoomID"`
User Account `gorm:"foreignkey:UserID"`
RoomID int64
UserID int64
}
Message is model represent message from chat in database
Click to show internal directories.
Click to hide internal directories.